==> nextcloud-12.0.3.tar.bz2: nextcloud/apps/survey_client/l10n/zh_CN.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "使用情况调查",
    "Sent on: {on}" : "已发送:{on}",
    "An error occurred while sending your report." : "发送报告时发生了错误。",
    "App list <em>(for each app: name, version, enabled status)</em>" : "应用列表 <em>(对于每个应用：名称、版本、启用状态)</em>",
    "Database environment <em>(type, version, database size)</em>" : "数据库环境<em>(类型,版本,数据库大小)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "加密信息<em>(是否已启用?哪个是默认的模块)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "分享量<em>(per type and permission setting)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP 环境<em>(版本,内存限制,最大执行时间,最大文件尺寸)",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "服务器实例详情 <em>(版本、memcache 用量、锁定/预览/头像的状态)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "统计<em>(number of: files, users, storages per type, comments and tags)</em>",
    "Help improve Nextcloud" : "帮助改进 Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "你想通给我们提供一些关于你的安装及使用情况的匿名数据来帮忙改进 Nextcloud 吗？你可以随时在管理员菜单的设置中关闭它.",
    "Not now" : "以后再说",
    "Send usage" : "发送使用情况",
    "Never" : "永不",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "你可以通过发送一些关于您当前安装及使用的数据来帮助我们改进Nextcloud.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "我们非常注重您的隐私信息.默认情况下数据发送是禁用的,而且你可以选择开启,当然这也是匿名的.你可以设置哪一些信息可以与我们分享.当收到一个报告时,先前的数据将会被清理.上传一份报告来删除当前已储存在服务器的信息.",
    "Send new report now" : "立即发送新报告",
    "Send usage survey monthly" : "按月发送使用情况",
    "Data to send" : "发送数据",
    "Last report" : "最后上报",
    "Sent on: %s" : "已发送:%s",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "应用列表<em>(foreach app:name,version,is enabled?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "服务器实例详情<em>(version, memcache used, locking/previews/avatars enabled?)</em>版本",
    "You can help us to improve Nextcloud be sending us some data about your current setup and usage." : "你可以通过发送一些关于您当前安装及使用的数据来帮助我们改进Nextcloud.",
    "We take your privacy seriously. The data are anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data are send and always see the last report send to us. When the server receives a new report of your instance, all entries from previous reports are removed. In case you disable one of the settings below, you can send a new report, to delete the data, that is currently stored on the server." : "我们非常注重您的隐私信息.默认情况下数据发送是禁用的,而且你可以选择开启,当然这也是匿名的.你可以设置哪一些信息可以与我们分享.当收到一个报告时,先前的数据将会被清理.上传一份报告来删除当前已储存在服务器的信息.",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "你可以通过发送一些关于您当前安装及使用的数据来帮助我们改进Nextcloud.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "我们非常注重您的隐私信息.默认情况下数据发送是禁用的,而且你可以选择开启,当然这也是匿名的.你可以设置哪一些信息可以与我们分享.当收到一个报告时,先前的数据将会被清理.上传一份报告来删除当前已储存在服务器的信息."
},
"nplurals=1; plural=0;");

==> nextcloud-13.0.2.tar.bz2: nextcloud/apps/survey_client/l10n/zh_CN.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "使用情况调查",
    "An error occurred while sending your report." : "发送报告时发生了错误。",
    "App list <em>(for each app: name, version, enabled status)</em>" : "应用列表 <em>(对于每个应用：名称、版本、启用状态)</em>",
    "Database environment <em>(type, version, database size)</em>" : "数据库环境<em>(类型,版本,数据库大小)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "加密信息<em>(是否已启用?哪个是默认的模块)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "分享量<em>(per type and permission setting)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP 环境<em>(版本,内存限制,最大执行时间,最大文件尺寸)",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "服务器实例详情 <em>(版本、memcache 用量、锁定/预览/头像的状态)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "统计<em>(number of: files, users, storages per type, comments and tags)</em>",
    "Help improve Nextcloud" : "帮助改进 Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "你想通给我们提供一些关于你的安装及使用情况的匿名数据来帮忙改进 Nextcloud 吗？你可以随时在管理员菜单的设置中关闭它.",
    "Not now" : "以后再说",
    "Send usage" : "发送使用情况",
    "Never" : "永不",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "你可以通过发送一些关于您当前安装及使用的数据来帮助我们改进Nextcloud.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "我们非常注重您的隐私信息.默认情况下数据发送是禁用的,而且你可以选择开启,当然这也是匿名的.你可以设置哪一些信息可以与我们分享.当收到一个报告时,先前的数据将会被清理.上传一份报告来删除当前已储存在服务器的信息.",
    "Send new report now" : "立即发送新报告",
    "Send usage survey monthly" : "按月发送使用情况",
    "Data to send" : "发送数据",
    "Last report" : "最后上报",
    "Sent on: {on}" : "已发送:{on}",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "应用列表<em>(foreach app:name,version,is enabled?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "服务器实例详情<em>(version, memcache used, locking/previews/avatars enabled?)</em>版本",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "你可以通过发送一些关于您当前安装及使用的数据来帮助我们改进Nextcloud.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "我们非常注重您的隐私信息.默认情况下数据发送是禁用的,而且你可以选择开启,当然这也是匿名的.你可以设置哪一些信息可以与我们分享.当收到一个报告时,先前的数据将会被清理.上传一份报告来删除当前已储存在服务器的信息.",
    "Sent on: %s" : "已发送:%s"
},
"nplurals=1; plural=0;");
